@@ -7,7 +7,7 @@ vif<-function(mod){
 
 
 vif.lm <- function(mod) {
-  # version by H. Nilsson, last modified 17 Jan 05 by J. Fox
+  # version by H. Nilsson, last modified 23 Jan 05 by J. Fox
   v <- vcov(mod)
   assign <- attributes(model.matrix(mod))$assign
   if (names(coefficients(mod)[1]) == "(Intercept)") {
@@ -19,12 +19,14 @@ vif.lm <- function(mod) {
   n.terms <- length(terms)
   if (n.terms < 2) stop("model contains fewer than 2 terms")
   R <- cov2cor(v)
+  detR <- det(R)
   result <- matrix(0, n.terms, 3)
   rownames(result) <- terms
   colnames(result) <- c("GVIF", "Df", "GVIF^(1/2Df)")
   for (term in 1:n.terms) {
     subs <- which(assign == term)
-    result[term, 1] <- det(as.matrix(R[subs, subs])) * det(as.matrix(R[-subs, -subs])) / det(R)
+    result[term, 1] <- det(as.matrix(R[subs, subs])) *
+        det(as.matrix(R[-subs, -subs])) / detR
     result[term, 2] <- length(subs)
   }
   if (all(result[, 2] == 1)) result <- result[, 1]
